==> WinBinder-0.30.101.tgz: Code/tests/tests.rc.php <==
<?php

// Control identifiers

if(!defined("IDD_DLG1001")) define("IDD_DLG1001", 1001);
if(!defined("ID_EXIT")) define("ID_EXIT", 1002);
if(!defined("IDC_TABCONTROL1003")) define("IDC_TABCONTROL1003", 1003);
if(!defined("ID_RESULT")) define("ID_RESULT", 1048);
if(!defined("IDC_TOOLBAR1025")) define("IDC_TOOLBAR1025", 1025);
if(!defined("IDD_DLG1027")) define("IDD_DLG1027", 1027);
if(!defined("ID_TREE")) define("ID_TREE", 801);
if(!defined("IDC_UPDOWN1027")) define("IDC_UPDOWN1027", 1027);
if(!defined("IDC_BUTTON1035")) define("IDC_BUTTON1035", 1035);
if(!defined("IDC_BUTTON1036")) define("IDC_BUTTON1036", 1036);
if(!defined("IDC_BUTTON1037")) define("IDC_BUTTON1037", 1037);
if(!defined("IDC_BUTTON1039")) define("IDC_BUTTON1039", 1039);
if(!defined("ID_HANDLERS")) define("ID_HANDLERS", 1047);
if(!defined("IDC_SLIDER1049")) define("IDC_SLIDER1049", 1049);
if(!defined("ID_TIME")) define("ID_TIME", 1050);
if(!defined("IDC_PROGRESSBAR1051")) define("IDC_PROGRESSBAR1051", 1051);

// Create window

$mainwin = wb_create_window(NULL, 100, "Sample WinBinder application", WBC_CENTER, WBC_CENTER, 560, 462, WBC_INVISIBLE | WBC_COLLAPSED, 0);

// Insert controls

wb_create_control($mainwin, TabControl, "", 4, 36, 545, 277, IDC_TABCONTROL1003, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, PushButton, "&Fechar", 498, 318, 51, 45, ID_EXIT, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, PushButton, "", 261, 321, 40, 41, IDC_BUTTON1035, WBC_VISIBLE | WBC_ENABLED);
$_tmp_ctrl_ = wb_create_control($mainwin, PushButton, "hyper.ico", 306, 321, 40, 41, IDC_BUTTON1036, WBC_VISIBLE | WBC_ENABLED);
wb_set_image($_tmp_ctrl_, '../res/hyper.ico', 0, GREEN); unset($_tmp_ctrl_);
$_tmp_ctrl_ = wb_create_control($mainwin, PushButton, "ok.bmp", 351, 321, 40, 41, IDC_BUTTON1037, WBC_VISIBLE | WBC_ENABLED);
wb_set_image($_tmp_ctrl_, '../res/ok.bmp', 0, GREEN); unset($_tmp_ctrl_);
wb_create_control($mainwin, PushButton, "Zero", 215, 321, 40, 41, IDC_BUTTON1039, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, Label, "GDI / USER", 397, 369, 146, 16, ID_HANDLERS, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT);
wb_create_control($mainwin, EditBox, "(Results)", 4, 318, 206, 45, ID_RESULT, WBC_VISIBLE | WBC_ENABLED | WBC_MULTILINE);
wb_create_control($mainwin, Slider, "", 302, 364, 92, 21, IDC_SLIDER1049, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, Label, "Time:", 215, 369, 81, 16, ID_TIME, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, Gauge, "IDC_PROGRESSBAR1051", 6, 369, 206, 14, IDC_PROGRESSBAR1051, WBC_VISIBLE | WBC_ENABLED);

// End controls

?>

==> WinBinder-0.31.104.tgz: Code/tests/tests.rc.php <==
<?php

// Control identifiers

if(!defined("IDD_DLG1001")) define("IDD_DLG1001", 1001);
if(!defined("ID_EXIT")) define("ID_EXIT", 1002);
if(!defined("IDC_TABCONTROL1003")) define("IDC_TABCONTROL1003", 1003);
if(!defined("ID_RESULT")) define("ID_RESULT", 1048);
if(!defined("IDC_TOOLBAR1025")) define("IDC_TOOLBAR1025", 1025);
if(!defined("IDD_DLG1027")) define("IDD_DLG1027", 1027);
if(!defined("ID_TREE")) define("ID_TREE", 801);
if(!defined("IDC_UPDOWN1027")) define("IDC_UPDOWN1027", 1027);
if(!defined("IDC_BUTTON1035")) define("IDC_BUTTON1035", 1035);
if(!defined("IDC_BUTTON1036")) define("IDC_BUTTON1036", 1036);
if(!defined("IDC_BUTTON1037")) define("IDC_BUTTON1037", 1037);
if(!defined("IDC_BUTTON1039")) define("IDC_BUTTON1039", 1039);
if(!defined("ID_GDI")) define("ID_GDI", 1047);
if(!defined("IDC_SLIDER1049")) define("IDC_SLIDER1049", 1049);
if(!defined("ID_TIME")) define("ID_TIME", 1050);
if(!defined("IDC_PROGRESSBAR1051")) define("IDC_PROGRESSBAR1051", 1051);

// Create window

$mainwin = wb_create_window(NULL, 100, "Sample WinBinder application", WBC_CENTER, WBC_CENTER, 560, 462, WBC_INVISIBLE | WBC_COLLAPSED | WBC_NOTIFY, 3);

// Insert controls

wb_create_control($mainwin, TabControl, "", 4, 36, 545, 277, IDC_TABCONTROL1003, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, PushButton, "&Fechar", 498, 318, 51, 45, ID_EXIT, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, PushButton, "", 261, 321, 40, 41, IDC_BUTTON1035, WBC_VISIBLE | WBC_ENABLED);
$_tmp_ctrl_ = wb_create_control($mainwin, PushButton, "hyper.ico", 306, 321, 40, 41, IDC_BUTTON1036, WBC_VISIBLE | WBC_ENABLED);
wb_set_image($_tmp_ctrl_, '../res/hyper.ico', 0, GREEN); unset($_tmp_ctrl_);
$_tmp_ctrl_ = wb_create_control($mainwin, PushButton, "ok.bmp", 351, 321, 40, 41, IDC_BUTTON1037, WBC_VISIBLE | WBC_ENABLED);
wb_set_image($_tmp_ctrl_, '../res/ok.bmp', 0, GREEN); unset($_tmp_ctrl_);
wb_create_control($mainwin, PushButton, "Zero", 215, 321, 40, 41, IDC_BUTTON1039, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, Label, "GDI / USER", 403, 369, 146, 16, ID_GDI, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT);
wb_create_control($mainwin, EditBox, "(Results)", 4, 318, 206, 45, ID_RESULT, WBC_VISIBLE | WBC_ENABLED | WBC_LINES);
wb_create_control($mainwin, Slider, "", 397, 323, 92, 36, IDC_SLIDER1049, WBC_VISIBLE | WBC_ENABLED | WBC_LINES);
wb_create_control($mainwin, Label, "Time:", 215, 369, 81, 16, ID_TIME, WBC_VISIBLE | WBC_ENABLED | WBC_LINES);
wb_create_control($mainwin, Gauge, "IDC_PROGRESSBAR1051", 6, 369, 206, 14, IDC_PROGRESSBAR1051, WBC_VISIBLE | WBC_ENABLED);

// End controls

?>
